@@ -9,8 +9,8 @@ def main():
     from reb import Pattern
 
     ap = argparse.ArgumentParser()
-    ap.add_argument('-p', '--pattern', help='import path of the pattern object')
-    ap.add_argument('-i', '--input', help='file to extract info', type=Path)
+    ap.add_argument('-p', '--pattern', help='import path of the pattern object', required=True)
+    ap.add_argument('-i', '--input', help='file to extract info', type=Path, required=True)
     ap.add_argument('-e', '--engine', help='which engine to use', default='plain', choices=['plain', 'vm'])
     args = ap.parse_args()
     
